/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TEST_SKELETON_SKEL_H__
#define __TEST_SKELETON_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct test_skeleton {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *data;
		struct bpf_map *rodata;
		struct bpf_map *bss;
		struct bpf_map *kconfig;
	} maps;
	struct {
		struct bpf_program *handler;
	} progs;
	struct {
		struct bpf_link *handler;
	} links;
	struct test_skeleton__bss {
		char in3;
		char __pad0[63];
		long long int in4;
		struct s in5;
		char out3;
		long long int out4;
		int out6;
		_Bool bpf_syscall;
		int kern_ver;
		char __pad1[0];
		struct s handler_out5;
	} *bss;
	struct test_skeleton__data {
		int in1;
		long long int in2;
		int out1;
		long long int out2;
	} *data;
	struct test_skeleton__kconfig {
		int LINUX_KERNEL_VERSION;
		_Bool CONFIG_BPF_SYSCALL;
	} *kconfig;
	struct test_skeleton__rodata {
		int in6;
	} *rodata;
};

static void
test_skeleton__destroy(struct test_skeleton *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_skeleton__create_skeleton(struct test_skeleton *obj);

static inline struct test_skeleton *
test_skeleton__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_skeleton *obj;

	obj = (typeof(obj))calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (test_skeleton__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	test_skeleton__destroy(obj);
	return NULL;
}

static inline struct test_skeleton *
test_skeleton__open(void)
{
	return test_skeleton__open_opts(NULL);
}

static inline int
test_skeleton__load(struct test_skeleton *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_skeleton *
test_skeleton__open_and_load(void)
{
	struct test_skeleton *obj;

	obj = test_skeleton__open();
	if (!obj)
		return NULL;
	if (test_skeleton__load(obj)) {
		test_skeleton__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
test_skeleton__attach(struct test_skeleton *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_skeleton__detach(struct test_skeleton *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
test_skeleton__create_skeleton(struct test_skeleton *obj)
{
	struct bpf_object_skeleton *s;

	s = (typeof(s))calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "test_skeleton";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 4;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (typeof(s->maps))calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "test_ske.data";
	s->maps[0].map = &obj->maps.data;
	s->maps[0].mmaped = (void **)&obj->data;

	s->maps[1].name = "test_ske.rodata";
	s->maps[1].map = &obj->maps.rodata;
	s->maps[1].mmaped = (void **)&obj->rodata;

	s->maps[2].name = "test_ske.bss";
	s->maps[2].map = &obj->maps.bss;
	s->maps[2].mmaped = (void **)&obj->bss;

	s->maps[3].name = "test_sk.kconfig";
	s->maps[3].map = &obj->maps.kconfig;
	s->maps[3].mmaped = (void **)&obj->kconfig;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (typeof(s->progs))calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "handler";
	s->progs[0].prog = &obj->progs.handler;
	s->progs[0].link = &obj->links.handler;

	s->data_sz = 7080;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x28\x16\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x16\0\
\x01\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x23\x0b\0\0\0\0\0\x18\x01\0\0\
\x6c\0\0\0\0\0\0\0\0\0\0\0\x73\x31\x0b\0\0\0\0\0\x71\x23\x0a\0\0\0\0\0\x73\x31\
\x0a\0\0\0\0\0\x71\x23\x09\0\0\0\0\0\x73\x31\x09\0\0\0\0\0\x71\x23\x08\0\0\0\0\
\0\x73\x31\x08\0\0\0\0\0\x71\x23\x07\0\0\0\0\0\x73\x31\x07\0\0\0\0\0\x71\x23\
\x06\0\0\0\0\0\x73\x31\x06\0\0\0\0\0\x71\x23\x05\0\0\0\0\0\x73\x31\x05\0\0\0\0\
\0\x71\x23\x04\0\0\0\0\0\x73\x31\x04\0\0\0\0\0\x71\x23\x03\0\0\0\0\0\x73\x31\
\x03\0\0\0\0\0\x71\x23\x02\0\0\0\0\0\x73\x31\x02\0\0\0\0\0\x71\x23\x01\0\0\0\0\
\0\x73\x31\x01\0\0\0\0\0\x71\x22\0\0\0\0\0\0\x73\x21\0\0\0\0\0\0\x18\x01\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x63\x12\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x11\0\0\0\0\0\0\
\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x12\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x71\x11\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x73\x12\
\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x11\0\0\0\0\0\0\x18\x02\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x12\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x71\x11\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x73\x12\0\0\0\0\0\
\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\
\x11\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xb4\0\
\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xff\xff\xff\xff\0\0\0\0\xff\xff\xff\xff\xff\xff\
\xff\xff\xff\xff\xff\xff\0\0\0\0\xff\xff\xff\xff\xff\xff\xff\xff\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x47\x50\x4c\0\x01\
\x11\x01\x25\x0e\x13\x05\x03\x0e\x10\x17\x1b\x0e\x11\x01\x12\x06\0\0\x02\x34\0\
\x03\x0e\x49\x13\x3f\x19\x3a\x0b\x3b\x0b\x02\x18\0\0\x03\x24\0\x03\x0e\x3e\x0b\
\x0b\x0b\0\0\x04\x34\0\x03\x0e\x49\x13\x3f\x19\x3a\x0b\x3b\x0b\x88\x01\x0f\x02\
\x18\0\0\x05\x13\x01\x03\x0e\x0b\x0b\x3a\x0b\x3b\x0b\0\0\x06\x0d\0\x03\x0e\x49\
\x13\x3a\x0b\x3b\x0b\x38\x0b\0\0\x07\x26\0\x49\x13\0\0\x08\x35\0\x49\x13\0\0\
\x09\x2e\x01\x11\x01\x12\x06\x40\x18\x97\x42\x19\x03\x0e\x3a\x0b\x3b\x0b\x27\
\x19\x49\x13\x3f\x19\0\0\x0a\x34\0\x03\x0e\x49\x13\x3a\x0b\x3b\x0b\x02\x18\0\0\
\x0b\x05\0\x03\x0e\x3a\x0b\x3b\x0b\x49\x13\0\0\x0c\x01\x01\x49\x13\0\0\x0d\x21\
\0\x49\x13\x37\x0b\0\0\x0e\x24\0\x03\x0e\x0b\x0b\x3e\x0b\0\0\x0f\x34\0\x03\x0e\
\x49\x13\x3f\x19\x3a\x0b\x3b\x0b\x3c\x19\x02\x18\0\0\x10\x0f\0\x49\x13\0\0\x11\
\x26\0\0\0\0\x17\x02\0\0\x04\0\0\0\0\0\x08\x01\0\0\0\0\x0c\0\x4a\0\0\0\0\0\0\0\
\x60\0\0\0\0\0\0\0\0\0\0\0\x40\x02\0\0\x02\xc4\0\0\0\x3f\0\0\0\x01\x0e\x09\x03\
\0\0\0\0\0\0\0\0\x03\xc8\0\0\0\x05\x04\x02\xcc\0\0\0\x5b\0\0\0\x01\x0f\x09\x03\
\0\0\0\0\0\0\0\0\x03\xd0\0\0\0\x05\x08\x02\xde\0\0\0\x77\0\0\0\x01\x12\x09\x03\
\0\0\0\0\0\0\0\0\x03\xe2\0\0\0\x06\x01\x04\xe7\0\0\0\x5b\0\0\0\x01\x13\x40\x09\
\x03\0\0\0\0\0\0\0\0\x02\xeb\0\0\0\xa9\0\0\0\x01\x14\x09\x03\0\0\0\0\0\0\0\0\
\x05\xf3\0\0\0\x0c\x01\x08\x06\xef\0\0\0\x3f\0\0\0\x01\x09\0\x06\xf1\0\0\0\x5b\
\0\0\0\x01\x0a\x04\0\x02\xf5\0\0\0\xdf\0\0\0\x01\x17\x09\x03\0\0\0\0\0\0\0\0\
\x07\xe4\0\0\0\x08\x3f\0\0\0\x02\xf9\0\0\0\x3f\0\0\0\x01\x1a\x09\x03\0\0\0\0\0\
\0\0\0\x02\xfe\0\0\0\x5b\0\0\0\x01\x1b\x09\x03\0\0\0\0\0\0\0\0\x02\x03\x01\0\0\
\x77\0\0\0\x01\x1e\x09\x03\0\0\0\0\0\0\0\0\x02\x08\x01\0\0\x5b\0\0\0\x01\x1f\
\x09\x03\0\0\0\0\0\0\0\0\x02\x0d\x01\0\0\x3f\0\0\0\x01\x20\x09\x03\0\0\0\0\0\0\
\0\0\x02\x12\x01\0\0\x67\x01\0\0\x01\x24\x09\x03\0\0\0\0\0\0\0\0\x03\x1e\x01\0\
\0\x02\x01\x02\x24\x01\0\0\x3f\0\0\0\x01\x25\x09\x03\0\0\0\0\0\0\0\0\x09\0\0\0\
\0\0\0\0\0\x40\x02\0\0\x01\x5a\x77\x01\0\0\x01\x28\x3f\0\0\0\x0a\x2d\x01\0\0\
\xbd\x01\0\0\x01\x2a\x09\x03\x6c\0\0\0\0\0\0\0\x0b\x7f\x01\0\0\x01\x28\x14\x02\
\0\0\0\x08\xa9\0\0\0\x02\x32\x01\0\0\xd7\x01\0\0\x01\x39\x09\x03\0\0\0\0\0\0\0\
\0\x0c\x77\0\0\0\x0d\xe3\x01\0\0\x04\0\x0e\x3b\x01\0\0\x08\x07\x0f\x4f\x01\0\0\
\x67\x01\0\0\x01\x22\x09\x03\0\0\0\0\0\0\0\0\x0f\x62\x01\0\0\x3f\0\0\0\x01\x23\
\x09\x03\0\0\0\0\0\0\0\0\x10\x19\x02\0\0\x11\0\x63\x6c\x61\x6e\x67\x20\x76\x65\
\x72\x73\x69\x6f\x6e\x20\x31\x31\x2e\x30\x2e\x30\x20\x28\x52\x65\x64\x20\x48\
\x61\x74\x20\x31\x31\x2e\x30\x2e\x30\x2d\x30\x2e\x32\x2e\x72\x63\x32\x2e\x6d\
\x6f\x64\x75\x6c\x65\x5f\x65\x6c\x38\x2e\x34\x2e\x30\x2b\x35\x33\x33\x2b\x35\
\x30\x31\x39\x31\x35\x37\x37\x29\0\x70\x72\x6f\x67\x73\x2f\x74\x65\x73\x74\x5f\
\x73\x6b\x65\x6c\x65\x74\x6f\x6e\x2e\x63\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\
\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\
\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x32\x35\x37\x2e\x65\x6c\x38\x2f\x6c\x69\x6e\
\x75\x78\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x32\x35\x37\x2e\x65\x6c\x38\x2e\x78\
\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\
\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\0\x69\x6e\x31\0\x69\
\x6e\x74\0\x69\x6e\x32\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\x20\x69\x6e\x74\0\
\x69\x6e\x33\0\x63\x68\x61\x72\0\x69\x6e\x34\0\x69\x6e\x35\0\x61\0\x62\0\x73\0\
\x69\x6e\x36\0\x6f\x75\x74\x31\0\x6f\x75\x74\x32\0\x6f\x75\x74\x33\0\x6f\x75\
\x74\x34\0\x6f\x75\x74\x36\0\x62\x70\x66\x5f\x73\x79\x73\x63\x61\x6c\x6c\0\x5f\
\x42\x6f\x6f\x6c\0\x6b\x65\x72\x6e\x5f\x76\x65\x72\0\x6f\x75\x74\x35\0\x5f\x6c\
\x69\x63\x65\x6e\x73\x65\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\
\x54\x59\x50\x45\x5f\x5f\0\x43\x4f\x4e\x46\x49\x47\x5f\x42\x50\x46\x5f\x53\x59\
\x53\x43\x41\x4c\x4c\0\x4c\x49\x4e\x55\x58\x5f\x4b\x45\x52\x4e\x45\x4c\x5f\x56\
\x45\x52\x53\x49\x4f\x4e\0\x68\x61\x6e\x64\x6c\x65\x72\0\x63\x74\x78\0\x9f\xeb\
\x01\0\x18\0\0\0\0\0\0\0\0\x03\0\0\0\x03\0\0\x15\x02\0\0\0\0\0\0\0\0\0\x02\x02\
\0\0\0\0\0\0\0\0\0\0\x0a\0\0\0\0\0\0\0\0\x01\0\0\x0d\x04\0\0\0\x01\0\0\0\x01\0\
\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\x09\0\0\0\x01\0\0\x0c\x03\0\0\0\
\x3a\x01\0\0\0\0\0\x0e\x04\0\0\0\x01\0\0\0\x3e\x01\0\0\0\0\0\x01\x08\0\0\0\x40\
\0\0\x01\x4c\x01\0\0\0\0\0\x0e\x07\0\0\0\x01\0\0\0\x50\x01\0\0\0\0\0\x01\x01\0\
\0\0\x08\0\0\x01\x55\x01\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\x59\x01\0\0\0\0\0\
\x0e\x07\0\0\0\x01\0\0\0\x5d\x01\0\0\x02\0\0\x04\x0c\0\0\0\x5f\x01\0\0\x04\0\0\
\0\0\0\0\0\x61\x01\0\0\x07\0\0\0\x20\0\0\0\x63\x01\0\0\0\0\0\x0e\x0c\0\0\0\x01\
\0\0\0\0\0\0\0\0\0\0\x0a\x0f\0\0\0\0\0\0\0\0\0\0\x09\x04\0\0\0\x67\x01\0\0\0\0\
\0\x0e\x0e\0\0\0\x01\0\0\0\x6b\x01\0\0\0\0\0\x0e\x04\0\0\0\x01\0\0\0\x70\x01\0\
\0\0\0\0\x0e\x07\0\0\0\x01\0\0\0\x75\x01\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\x7a\
\x01\0\0\0\0\0\x0e\x07\0\0\0\x01\0\0\0\x7f\x01\0\0\0\0\0\x0e\x04\0\0\0\x01\0\0\
\0\x84\x01\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x04\x8a\x01\0\0\0\0\0\x0e\x16\0\0\0\
\x01\0\0\0\x96\x01\0\0\0\0\0\x0e\x04\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x09\x0c\0\0\
\0\x9f\x01\0\0\0\0\0\x0e\x19\0\0\0\0\0\0\0\xac\x01\0\0\0\0\0\x0e\x16\0\0\0\x02\
\0\0\0\xbf\x01\0\0\0\0\0\x0e\x04\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x09\
\0\0\0\x1e\0\0\0\x04\0\0\0\xd4\x01\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\xe8\x01\0\
\0\0\0\0\x0e\x1d\0\0\0\x01\0\0\0\xf1\x01\0\0\x09\0\0\x0f\0\0\0\0\x0a\0\0\0\0\0\
\0\0\x01\0\0\0\x0b\0\0\0\0\0\0\0\x08\0\0\0\x0d\0\0\0\0\0\0\0\x0c\0\0\0\x13\0\0\
\0\0\0\0\0\x01\0\0\0\x14\0\0\0\0\0\0\0\x08\0\0\0\x15\0\0\0\0\0\0\0\x04\0\0\0\
\x17\0\0\0\0\0\0\0\x01\0\0\0\x18\0\0\0\0\0\0\0\x04\0\0\0\x1a\0\0\0\x6c\0\0\0\
\x0c\0\0\0\xf6\x01\0\0\x04\0\0\x0f\0\0\0\0\x06\0\0\0\0\0\0\0\x04\0\0\0\x08\0\0\
\0\0\0\0\0\x08\0\0\0\x11\0\0\0\0\0\0\0\x04\0\0\0\x12\0\0\0\0\0\0\0\x08\0\0\0\
\xfc\x01\0\0\x02\0\0\x0f\0\0\0\0\x1b\0\0\0\0\0\0\0\x01\0\0\0\x1c\0\0\0\0\0\0\0\
\x04\0\0\0\x05\x02\0\0\x01\0\0\x0f\0\0\0\0\x10\0\0\0\0\0\0\0\x04\0\0\0\x0d\x02\
\0\0\x01\0\0\x0f\0\0\0\0\x1f\0\0\0\0\0\0\0\x04\0\0\0\0\x63\x74\x78\0\x69\x6e\
\x74\0\x68\x61\x6e\x64\x6c\x65\x72\0\x72\x61\x77\x5f\x74\x70\x2f\x73\x79\x73\
\x5f\x65\x6e\x74\x65\x72\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\
\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x34\x2e\x31\
\x38\x2e\x30\x2d\x32\x35\x37\x2e\x65\x6c\x38\x2f\x6c\x69\x6e\x75\x78\x2d\x34\
\x2e\x31\x38\x2e\x30\x2d\x32\x35\x37\x2e\x65\x6c\x38\x2e\x78\x38\x36\x5f\x36\
\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\
\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x74\x65\
\x73\x74\x5f\x73\x6b\x65\x6c\x65\x74\x6f\x6e\x2e\x63\0\x09\x6f\x75\x74\x35\x20\
\x3d\x20\x69\x6e\x35\x3b\0\x09\x6f\x75\x74\x31\x20\x3d\x20\x69\x6e\x31\x3b\0\
\x09\x6f\x75\x74\x32\x20\x3d\x20\x69\x6e\x32\x3b\0\x09\x6f\x75\x74\x33\x20\x3d\
\x20\x69\x6e\x33\x3b\0\x09\x6f\x75\x74\x34\x20\x3d\x20\x69\x6e\x34\x3b\0\x09\
\x62\x70\x66\x5f\x73\x79\x73\x63\x61\x6c\x6c\x20\x3d\x20\x43\x4f\x4e\x46\x49\
\x47\x5f\x42\x50\x46\x5f\x53\x59\x53\x43\x41\x4c\x4c\x3b\0\x09\x6b\x65\x72\x6e\
\x5f\x76\x65\x72\x20\x3d\x20\x4c\x49\x4e\x55\x58\x5f\x4b\x45\x52\x4e\x45\x4c\
\x5f\x56\x45\x52\x53\x49\x4f\x4e\x3b\0\x09\x6f\x75\x74\x36\x20\x3d\x20\x69\x6e\
\x36\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x30\x3b\0\x69\x6e\x31\0\x6c\x6f\x6e\
\x67\x20\x6c\x6f\x6e\x67\x20\x69\x6e\x74\0\x69\x6e\x32\0\x63\x68\x61\x72\0\x69\
\x6e\x33\0\x69\x6e\x34\0\x73\0\x61\0\x62\0\x69\x6e\x35\0\x69\x6e\x36\0\x6f\x75\
\x74\x31\0\x6f\x75\x74\x32\0\x6f\x75\x74\x33\0\x6f\x75\x74\x34\0\x6f\x75\x74\
\x36\0\x5f\x42\x6f\x6f\x6c\0\x62\x70\x66\x5f\x73\x79\x73\x63\x61\x6c\x6c\0\x6b\
\x65\x72\x6e\x5f\x76\x65\x72\0\x68\x61\x6e\x64\x6c\x65\x72\x2e\x6f\x75\x74\x35\
\0\x43\x4f\x4e\x46\x49\x47\x5f\x42\x50\x46\x5f\x53\x59\x53\x43\x41\x4c\x4c\0\
\x4c\x49\x4e\x55\x58\x5f\x4b\x45\x52\x4e\x45\x4c\x5f\x56\x45\x52\x53\x49\x4f\
\x4e\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\
\x5f\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x64\x61\x74\x61\
\0\x2e\x6b\x63\x6f\x6e\x66\x69\x67\0\x2e\x72\x6f\x64\x61\x74\x61\0\x6c\x69\x63\
\x65\x6e\x73\x65\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x14\0\0\0\x14\0\0\0\x0c\x01\
\0\0\x20\x01\0\0\0\0\0\0\x08\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x05\0\0\0\x10\0\
\0\0\x11\0\0\0\x10\0\0\0\0\0\0\0\x22\0\0\0\x9c\0\0\0\x09\xc0\0\0\xe0\0\0\0\x22\
\0\0\0\xa9\0\0\0\x09\xb0\0\0\xf8\0\0\0\x22\0\0\0\xa9\0\0\0\x07\xb0\0\0\x10\x01\
\0\0\x22\0\0\0\xb6\0\0\0\x09\xb4\0\0\x28\x01\0\0\x22\0\0\0\xb6\0\0\0\x07\xb4\0\
\0\x40\x01\0\0\x22\0\0\0\xc3\0\0\0\x09\xb8\0\0\x58\x01\0\0\x22\0\0\0\xc3\0\0\0\
\x07\xb8\0\0\x70\x01\0\0\x22\0\0\0\xd0\0\0\0\x09\xbc\0\0\x88\x01\0\0\x22\0\0\0\
\xd0\0\0\0\x07\xbc\0\0\xa0\x01\0\0\x22\0\0\0\xdd\0\0\0\x10\xcc\0\0\xb8\x01\0\0\
\x22\0\0\0\xdd\0\0\0\x0e\xcc\0\0\xd0\x01\0\0\x22\0\0\0\0\x01\0\0\x0d\xd0\0\0\
\xe8\x01\0\0\x22\0\0\0\0\x01\0\0\x0b\xd0\0\0\0\x02\0\0\x22\0\0\0\x22\x01\0\0\
\x09\xc4\0\0\x18\x02\0\0\x22\0\0\0\x22\x01\0\0\x07\xc4\0\0\x30\x02\0\0\x22\0\0\
\0\x2f\x01\0\0\x02\xd8\0\0\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x01\x7a\x52\0\x08\
\x7c\x0b\x01\x0c\0\0\0\x18\0\0\0\x18\0\0\0\0\0\0\0\0\0\0\0\x40\x02\0\0\0\0\0\0\
\0\0\0\0\x84\0\0\0\x04\0\x2d\0\0\0\x08\x01\x01\xfb\x0e\x0d\0\x01\x01\x01\x01\0\
\0\0\x01\0\0\x01\x70\x72\x6f\x67\x73\0\0\x74\x65\x73\x74\x5f\x73\x6b\x65\x6c\
\x65\x74\x6f\x6e\x2e\x63\0\x01\0\0\0\0\x09\x02\0\0\0\0\0\0\0\0\x03\x28\x01\x05\
\x09\x0a\x19\x08\xa8\x05\x07\x06\x3c\x05\x09\x06\x3d\x05\x07\x06\x3c\x05\x09\
\x06\x3d\x05\x07\x06\x3c\x05\x09\x06\x3d\x05\x07\x06\x3c\x05\x10\x06\x40\x05\
\x0e\x06\x3c\x05\x0d\x06\x3d\x05\x0b\x06\x3c\x05\x09\x06\x39\x05\x07\x06\x3c\
\x05\x02\x06\x41\x02\x02\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x9b\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x01\0\0\x01\0\
\x06\0\x6c\0\0\0\0\0\0\0\x0c\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xde\0\0\0\
\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc9\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x74\0\0\0\x11\0\x08\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x68\0\
\0\0\x11\0\x06\0\x64\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x50\0\0\0\x12\0\x03\0\0\0\
\0\0\0\0\0\0\x40\x02\0\0\0\0\0\0\x34\x01\0\0\x11\0\x05\0\0\0\0\0\0\0\0\0\x04\0\
\0\0\0\0\0\0\x2b\x01\0\0\x11\0\x05\0\x08\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x22\
\x01\0\0\x11\0\x06\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x19\x01\0\0\x11\0\x06\0\
\x40\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\x01\0\0\x11\0\x06\0\x48\0\0\0\0\0\0\0\
\x0c\0\0\0\0\0\0\0\xff\0\0\0\x11\0\x07\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x32\
\0\0\0\x11\0\x06\0\x68\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x2f\x01\0\0\x11\0\x05\0\
\x10\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x26\x01\0\0\x11\0\x05\0\x18\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\x1d\x01\0\0\x11\0\x06\0\x54\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\
\x14\x01\0\0\x11\0\x06\0\x58\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\xfa\0\0\0\x11\0\
\x06\0\x60\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\0\
\x18\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\xe0\0\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\
\xf8\0\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\x10\x01\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\
\x28\x01\0\0\0\0\0\0\x01\0\0\0\x12\0\0\0\x40\x01\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\
\0\x58\x01\0\0\0\0\0\0\x01\0\0\0\x13\0\0\0\x70\x01\0\0\0\0\0\0\x01\0\0\0\x0d\0\
\0\0\x88\x01\0\0\0\0\0\0\x01\0\0\0\x14\0\0\0\xa0\x01\0\0\0\0\0\0\x01\0\0\0\x05\
\0\0\0\xb8\x01\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\xd0\x01\0\0\0\0\0\0\x01\0\0\0\
\x06\0\0\0\xe8\x01\0\0\0\0\0\0\x01\0\0\0\x10\0\0\0\0\x02\0\0\0\0\0\0\x01\0\0\0\
\x0f\0\0\0\x18\x02\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\x1e\0\0\0\0\0\0\0\x01\0\0\0\
\x03\0\0\0\x37\0\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x53\0\0\0\0\0\0\0\x01\0\0\0\
\x0b\0\0\0\x6f\0\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x8c\0\0\0\0\0\0\0\x01\0\0\0\
\x0d\0\0\0\xa1\0\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\0\xd7\0\0\0\0\0\0\0\x01\0\0\0\
\x0f\0\0\0\xf6\0\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\x0b\x01\0\0\0\0\0\0\x01\0\0\0\
\x12\0\0\0\x20\x01\0\0\0\0\0\0\x01\0\0\0\x13\0\0\0\x35\x01\0\0\0\0\0\0\x01\0\0\
\0\x14\0\0\0\x4a\x01\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\x5f\x01\0\0\0\0\0\0\x01\0\
\0\0\x08\0\0\0\x7b\x01\0\0\0\0\0\0\x01\0\0\0\x10\0\0\0\x84\x01\0\0\0\0\0\0\x01\
\0\0\0\x03\0\0\0\xa9\x01\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\xcf\x01\0\0\0\0\0\0\
\x01\0\0\0\x07\0\0\0\xf7\x01\0\0\0\0\0\0\x01\0\0\0\x05\0\0\0\x0c\x02\0\0\0\0\0\
\0\x01\0\0\0\x06\0\0\0\x20\x02\0\0\0\0\0\0\0\0\0\0\x0c\0\0\0\x2c\x02\0\0\0\0\0\
\0\0\0\0\0\x0d\0\0\0\x38\x02\0\0\0\0\0\0\0\0\0\0\x0e\0\0\0\x44\x02\0\0\0\0\0\0\
\0\0\0\0\x13\0\0\0\x50\x02\0\0\0\0\0\0\0\0\0\0\x14\0\0\0\x5c\x02\0\0\0\0\0\0\0\
\0\0\0\x15\0\0\0\x68\x02\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\x74\x02\0\0\0\0\0\0\0\0\
\0\0\x10\0\0\0\x80\x02\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\x98\x02\0\0\0\0\0\0\0\0\0\
\0\x0a\0\0\0\xa4\x02\0\0\0\0\0\0\0\0\0\0\x0b\0\0\0\xb0\x02\0\0\0\0\0\0\0\0\0\0\
\x11\0\0\0\xbc\x02\0\0\0\0\0\0\0\0\0\0\x12\0\0\0\xd4\x02\0\0\0\0\0\0\x0a\0\0\0\
\x05\0\0\0\xe0\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\xf8\x02\0\0\0\0\0\0\x0a\0\0\
\0\x0f\0\0\0\x10\x03\0\0\0\0\0\0\0\0\0\0\x07\0\0\0\x2c\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x50\0\0\0\0\0\0\0\0\0\0\0\x03\0\
\0\0\x60\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x70\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\
\x80\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x90\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xa0\0\
\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xb0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xc0\0\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\0\xd0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xe0\0\0\0\0\0\0\0\
\0\0\0\0\x03\0\0\0\xf0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\x03\0\0\0\x10\x01\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x20\x01\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\x30\x01\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x1c\0\0\0\0\0\0\0\x01\0\0\0\
\x03\0\0\0\x3a\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\x2e\x64\x65\x62\x75\x67\x5f\
\x61\x62\x62\x72\x65\x76\0\x2e\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x2e\x42\x54\
\x46\x2e\x65\x78\x74\0\x2e\x62\x73\x73\0\x2e\x64\x65\x62\x75\x67\x5f\x73\x74\
\x72\0\x6b\x65\x72\x6e\x5f\x76\x65\x72\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\
\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\x72\0\x68\x61\x6e\x64\x6c\x65\x72\0\
\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x69\x6e\x66\x6f\0\x62\x70\x66\x5f\
\x73\x79\x73\x63\x61\x6c\x6c\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\
\x6c\x2e\x64\x65\x62\x75\x67\x5f\x6c\x69\x6e\x65\0\x2e\x72\x65\x6c\x2e\x65\x68\
\x5f\x66\x72\x61\x6d\x65\0\x74\x65\x73\x74\x5f\x73\x6b\x65\x6c\x65\x74\x6f\x6e\
\x2e\x63\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x72\
\x6f\x64\x61\x74\x61\0\x2e\x64\x61\x74\x61\0\x4c\x49\x4e\x55\x58\x5f\x4b\x45\
\x52\x4e\x45\x4c\x5f\x56\x45\x52\x53\x49\x4f\x4e\0\x43\x4f\x4e\x46\x49\x47\x5f\
\x42\x50\x46\x5f\x53\x59\x53\x43\x41\x4c\x4c\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\
\0\x6f\x75\x74\x36\0\x69\x6e\x36\0\x68\x61\x6e\x64\x6c\x65\x72\x2e\x6f\x75\x74\
\x35\0\x69\x6e\x35\0\x6f\x75\x74\x34\0\x69\x6e\x34\0\x6f\x75\x74\x33\0\x69\x6e\
\x33\0\x6f\x75\x74\x32\0\x69\x6e\x32\0\x6f\x75\x74\x31\0\x69\x6e\x31\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xab\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\xf0\x14\0\0\0\0\0\0\x38\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0f\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x3f\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\
\0\0\x40\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3b\
\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x80\x10\0\0\0\0\0\0\0\x01\0\0\
\0\0\0\0\x15\0\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xc3\0\0\0\x01\
\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x80\x02\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x08\0\0\0\x03\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xc0\x02\0\0\0\0\0\0\x78\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbb\0\0\0\x01\0\0\0\x02\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xc0\x02\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x75\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xc4\x02\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc8\x02\0\0\0\0\
\0\0\xde\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x5c\0\
\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa6\x03\0\0\0\0\0\0\x1b\x02\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x58\0\0\0\x09\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x80\x11\0\0\0\0\0\0\x30\x01\0\0\0\0\0\0\x15\0\
\0\0\x0a\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x27\0\0\0\x01\0\0\0\x30\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xc1\x05\0\0\0\0\0\0\x83\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\xf5\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x44\x07\0\0\0\0\0\0\x2d\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xf1\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xb0\x12\0\0\0\0\0\0\x10\x01\0\0\0\0\0\0\x15\0\0\0\x0d\0\0\0\x08\0\0\0\0\0\0\0\
\x10\0\0\0\0\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\x0c\
\0\0\0\0\0\0\x40\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x15\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc0\x13\0\0\0\0\0\0\
\x10\x01\0\0\0\0\0\0\x15\0\0\0\x0f\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\x91\0\0\0\x01\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb8\x0d\0\0\0\0\0\0\x30\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x8d\0\0\0\x09\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd0\x14\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\x15\0\0\0\x11\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x81\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe8\x0d\0\0\0\0\0\0\x88\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7d\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xe0\x14\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x15\0\0\0\x13\0\0\0\x08\0\
\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xb3\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x70\x0e\0\0\0\0\0\0\x10\x02\0\0\0\0\0\0\x01\0\0\0\x05\0\0\0\x08\0\0\0\0\0\
\0\0\x18\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __TEST_SKELETON_SKEL_H__ */
